@@ -1,6 +1,9 @@
 package printer
 
 import (
+	"fmt"
+	"os"
+
 	"github.com/armosec/kubescape/cautils"
 )
 
@@ -19,15 +22,16 @@ type IPrinter interface {
 	Score(score float32)
 }
 
-func GetPrinter(printFormat string, verboseMode bool) IPrinter {
-	switch printFormat {
-	case JsonFormat:
-		return NewJsonPrinter()
-	case JunitResultFormat:
-		return NewJunitPrinter()
-	case PrometheusFormat:
-		return NewPrometheusPrinter(verboseMode)
-	default:
-		return NewPrettyPrinter(verboseMode)
+func GetWriter(outputFile string) *os.File {
+	os.Remove(outputFile)
+	if outputFile != "" {
+		f, err := os.OpenFile(outputFile, os.O_APPEND|os.O_CREATE|os.O_WRONLY, 0644)
+		if err != nil {
+			fmt.Println("failed to open file for writing, reason: ", err.Error())
+			return os.Stdout
+		}
+		return f
 	}
+	return os.Stdout
+
 }
